Index: third_party/WebKit/Source/core/css/resolver/CSSVariableResolver.h |
diff --git a/third_party/WebKit/Source/core/css/resolver/CSSVariableResolver.h b/third_party/WebKit/Source/core/css/resolver/CSSVariableResolver.h |
index 81d69bd8ac721724e466a946dbd214cd86f6b2f6..c49b97f87c26d7d3d8f5b9f91b590b6f7d1f9b1b 100644 |
--- a/third_party/WebKit/Source/core/css/resolver/CSSVariableResolver.h |
+++ b/third_party/WebKit/Source/core/css/resolver/CSSVariableResolver.h |
@@ -32,12 +32,14 @@ private: |
// These return false if we encounter a reference to an invalid variable with no fallback |
// Resolves a range which may contain var() references |
bool resolveTokenRange(CSSParserTokenRange, Vector<CSSParserToken>& result); |
// Resolves the fallback (if present) of a var() reference, starting from the comma |
bool resolveFallback(CSSParserTokenRange, Vector<CSSParserToken>& result); |
// Resolves the contents of a var() reference |
bool resolveVariableReference(CSSParserTokenRange, Vector<CSSParserToken>& result); |
+ // Consumes and resolves an @apply rule |
+ void resolveApplyAtRule(CSSParserTokenRange&, Vector<CSSParserToken>& result); |
// These return null if the custom property is invalid |
@@ -32,12 +32,14 @@ private: |
// These return false if we encounter a reference to an invalid variable with no fallback |
- // Resolves a range which may contain var() references |
+ // Resolves a range which may contain var() references or @apply rules |
bool resolveTokenRange(CSSParserTokenRange, Vector<CSSParserToken>& result); |
// Resolves the fallback (if present) of a var() reference, starting from the comma |